/**
 * JASMINe
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.rules.osgi.api;

import java.util.Map;

import org.drools.KnowledgeBase;
import org.drools.RuleBase;
import org.drools.builder.KnowledgeBuilder;
import org.drools.compiler.PackageBuilder;
import org.drools.rule.Package;
import org.osgi.framework.Bundle;

/**
 * Define a service to add {@link Package} into a {@link RuleBase}.
 * @author Loris Bouzonnet
 */
public interface IPackageAdder {

    /**
     * Add a rules package into the providing {@link RuleBase}, by using the given {@link PackageBuilder}.
     * @param packageBuilder a package builder
     * @param ruleBase a rule base
     * @throws Exception if a package cannot be built or added to the rule base
     */
    void addPackage(KnowledgeBuilder packageBuilder, KnowledgeBase ruleBase) throws Exception;

    /**
     * @return the bundle containing rules
     */
    Bundle getBundle();

    /**
     * Get the globals defined for this package
     * @return a map (name,object)
     */
    Map<String, Object> getGlobals();

    /**
     * Get the targeted working memory name for the package
     * @return the name as String
     */
    String getWorkingMemoryName();

}
