/**
 * JASMINe
 * Copyright (C) 2008-2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.rules.osgi.impl;

import java.util.HashSet;
import java.util.Set;

import org.osgi.framework.Bundle;

/**
 * Delegate class loading to a set of bundles.
 * Because the working memory can contain rules coming from different bundles,
 * we need to keep a trace of this bundle to load classes during the execution of rules.
 * @author Loris Bouzonnet
 */
public class MultiBundleClassLoader extends ClassLoader {

    /**
     * Bundles providing rules.
     */
    private final Set<Bundle> bundles;

    public MultiBundleClassLoader(final ClassLoader parent) {
        super(parent);
        bundles = new HashSet<Bundle>();
    }

    public void addBundleClassLoader(final Bundle bundle) {
        bundles.add(bundle);
    }

    public void removeBundleClassLoader(final Bundle bundle) {
        bundles.remove(bundle);
    }

    @Override
    protected Class<?> findClass(final String name) throws ClassNotFoundException {
        // FIXME Find the active rule and directly use its bundle
        for(Bundle bundle : bundles) {
            try {
                return bundle.loadClass(name);
            } catch (ClassNotFoundException cnfe) {
                // Do nothing
            }
        }
        return Thread.currentThread().getContextClassLoader().loadClass(name);
    }

}
