/**
 * JASMINe
 * Copyright (C) 2006-2008 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.ow2.jasmine.rules.ra;

import java.util.logging.Level;
import java.util.logging.Logger;

import javax.resource.ResourceException;
import javax.resource.spi.ActivationSpec;
import javax.resource.spi.BootstrapContext;
import javax.resource.spi.ResourceAdapter;
import javax.resource.spi.ResourceAdapterInternalException;
import javax.resource.spi.endpoint.MessageEndpointFactory;
import javax.transaction.xa.XAResource;

import org.ow2.jasmine.rules.api.DroolsWorkingMemoryState;
import org.ow2.jasmine.rules.api.IDroolsWorkingMemory;
import org.ow2.jasmine.rules.ra.outbound.DroolsWorkingMemory;


/**
 * A resource adapter to manage the Drools working memory.
 */
public class DroolsResourceAdapter implements ResourceAdapter {

    /**
     * Logger.
     */
    private static Logger logger =
        Logger.getLogger(DroolsResourceAdapter.class.getName());

    /**
     * The Drools working memory.
     */
    private IDroolsWorkingMemory droolsWorkingMemory;

    // ------------------------------------------------------------------------
    // Implementation of the ResourceAdapter interface
    // ------------------------------------------------------------------------

    /**
     * Start the working memory.
     * @param context not used
     * @throws ResourceAdapterInternalException if the working memory cannot be started
     */
    public void start(final BootstrapContext context)
    throws ResourceAdapterInternalException {

        try {
            // Use an external classloader
            droolsWorkingMemory =
                new DroolsWorkingMemory(getClass().getClassLoader());
            // Start the working memory
            droolsWorkingMemory.start();
        } catch (Exception e) {
            logger.log(Level.SEVERE, "Cannot start the working memory", e);
            throw new ResourceAdapterInternalException(
                    "Cannot start the working memory", e);
        }
    }

    /**
     * Stop the working memory.
     */
    public void stop() {
        if(droolsWorkingMemory != null) {
            droolsWorkingMemory.stop(DroolsWorkingMemoryState.IDLE);
        }
    }

    public void endpointActivation(final MessageEndpointFactory arg0,
            final ActivationSpec arg1) throws ResourceException {
        // Do nothing
    }

    public void endpointDeactivation(final MessageEndpointFactory arg0,
            final ActivationSpec arg1) {
        // Do nothing
    }

    public XAResource[] getXAResources(final ActivationSpec[] arg0)
    throws ResourceException {
        // Do nothing
        return null;
    }
}
