/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.rules.manager.service;

import java.util.ArrayList;
import java.util.List;

/**
 * A data object that the server reporting the successes and failures when
 * saving a rule package
 *
 * @author Julien Nicoulaud
 * @see {@link RuleEngineService#saveRulePackage(RulePackage, String)}
 */
public class RulePackageSaveReport {

	// =========================================================================
	// Constants
	// =========================================================================

	/**
	 * The potential operations
	 */
	public final static String OPERATION_ACTIVATE = "OPERATION_ACTIVATE";
	public final static String OPERATION_DEACTIVATE = "OPERATION_DEACTIVATE";
	public final static String OPERATION_UPDATE = "OPERATION_UPDATE";
	public final static String OPERATION_SAVE = "OPERATION_SAVE";


	// =========================================================================
	// Variables
	// =========================================================================

	/**
	 * A list of the operations completed successfully
	 * Use the potential operations constants to feed this list.
	 */
	public List<String> successes = new ArrayList<String>();

	/**
	 * A list of the failures
	 * Each failure is a list of Strings following this structure by convention:
	 *  - Operation name/title
	 *  - Short statement describing the failure
	 *  - (Optional) A stack trace
	 */
	public List<ArrayList<String>> failures = new ArrayList<ArrayList<String>>();


	// =========================================================================
	// Public methods
	// =========================================================================

	/**
	 * Add a successful operation to the report
	 */
	public void addSuccess(final String operation) {
		successes.add(operation);
	}

	/**
	 * Add a failure to the report
	 *
	 * @param failure The name/title of the operation that failed
	 * @param cause Short statement describing the failure
	 * @param stackTrace A stack trace
	 */
	public void addFailure(final String failure, final String cause, final String stackTrace) {
		ArrayList<String> newFailure = new ArrayList<String>();
		newFailure.add(failure);
		newFailure.add(cause);
		newFailure.add(stackTrace);
		failures.add(newFailure);
	}

	/**
	 * Add a failure to the report
	 *
	 * @param failure The name/title of the operation that failed
	 * @param cause Short statement describing the failure
	 */
	public void addFailure(final String failure, final String cause) {
		ArrayList<String> newFailure = new ArrayList<String>();
		newFailure.add(failure);
		newFailure.add(cause);
		failures.add(newFailure);
	}
}
